@@ -30,7 +30,7 @@ class OrderFilter(django_filters.FilterSet):
         parent = super().qs.order_by("full_name")
         user = getattr(self.request, "user", None)
 
-        return queryset_rules_filter(user, parent, "order.manage_order")
+        return queryset_rules_filter(user, parent, "order.manage_order_rule")
 
     class Meta:
         model = Order
